@@ -67,7 +67,7 @@ public:
 
     QIcon icon() const override
     {
-        return QIcon::fromTheme(QStringLiteral("view-ldap-resource"));
+        return QIcon::fromTheme(QStringLiteral("kmail"));
     }
 
     int completionWeight() const override
@@ -106,7 +106,7 @@ protected:
     }
 
 private:
-    KLDAP::LdapClient *mLdapClient;
+    KLDAP::LdapClient *mLdapClient = nullptr;
     int mWeight;
 };
 
@@ -225,7 +225,7 @@ public:
     }
 
 private:
-    CompletionItem *mItem;
+    CompletionItem *mItem = nullptr;
 };
 
 CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
